@@ -6,13 +6,12 @@ BEGIN {
 	use strict;
 	use warnings;
 	
-	use Carp qw/croak/;
 	use Data::Dump qw/dump/;
 	use DBICx::AutoDoc; # if this fails this module fails
 	
 	use base 'Module::Install::Base';
 
-	our $VERSION = '0.01';
+	our $VERSION = '0.02';
 	use vars qw/$SCHEMA $AUTODOC_OUTPUT/;
 }
 
@@ -22,7 +21,7 @@ Module::Install::DBICx::AutoDoc - Use your Makefile to run DBICx::AutoDoc
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
@@ -30,9 +29,9 @@ In MakeFile.PL:
 	
 	dbicx_autodoc('doc'); # use name() or module_name() as Schema package
 	# or
-	dbix_autodoc('doc','My::Schema'); # better be in lib/
+	dbicx_autodoc('doc','My::Schema'); # better be in lib/
 	# or
-	dbix_autodoc({
+	dbicx_autodoc({
 		output => 'doc',
 		schema => 'My::Schema'
 	});
@@ -107,7 +106,7 @@ sub mk_makecmds {
 	
 	return  qq/autodoc :: all\n/.
 		qq/\t\$(PERLRUN) -I\$(INST_LIB) -MDBICx::AutoDoc -e '/.
-		$self->gen_dbicxautodoc().
+		$self->gen_dbicxautodoc($hash).
 		qq/'\n\ndistclean :: autodoc_clean\n\n/.
 		qq/autodoc_clean:\n\t\$(RM_RF) /.$hash->{output}.
 		qq/\n\n/;
@@ -126,14 +125,16 @@ sub gen_dbicxautodoc {
 	$self->_ck_hash($hash);
 	
 	my $str = Data::Dump::dump($hash);
-	return qq/my %h = $str; my \$a = DBICx::AutoDoc->new(%h)/;
+	my $ret = q/my $$h=/.$str.q/;DBICx::AutoDoc->new(%{$$h})->fill_all_templates()/;
+
+	return $ret;
 }
 
 sub _ck_hash {
 	my $self = shift;
 	my $hash = shift;
 	
-	croak "Recieved an ".ref($hash)." ref when we expected a HASH ref"
+	die "Recieved an ".ref($hash)." ref when we expected a HASH ref"
 		unless ref($hash) eq 'HASH';
 	
 }
